@@ -1,7 +1,7 @@
 package K_test;
 use lib "../..";
 use Test;
-BEGIN { plan test => 17}
+BEGIN { plan test => 19}
 
 use AI::NeuralNet::Kohonen;
 ok(1,1);
@@ -20,6 +20,17 @@ ok( ref $_->{input}, 'ARRAY');
 ok( $_->{input}->[0]->[0],1);
 ok( $_->{input}->[0]->[1],2);
 ok( $_->{input}->[0]->[2],3);
+ok($_->{map_dim_a},19);
+
+$_ = new AI::NeuralNet::Kohonen(
+	input => [
+		[1,2,3]
+	],
+	map_dim_x => 10,
+	map_dim_y => 20,
+);
+ok($_->{map_dim_a},15);
+
 
 # Node test
 my $node = new AI::NeuralNet::Kohonen::Node;
@@ -48,11 +59,12 @@ ok( $_->{input}->[0]->[2],0);
 ok( $_->{weight_dim}, 2);
 
 #$_->dump;
-#$_->tk_dump;
 $_->train;
 #warn "Trained.\n";
-#$_->tk_dump;
-
+@_ = $_->get_results;
+foreach (@_){
+	print join",",@$_,"\n";
+}
 
 ok(1,1);
 
